#
# spec file
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%{?sle15_python_module_pythons}
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define modname simpleeval
Name:           python-%{modname}
Version:        0.9.13
Release:        2.6
Summary:        A simple, safe single expression evaluator library
License:        MIT
URL:            https://github.com/danthedeckie/simpleeval
Source0:        https://files.pythonhosted.org/packages/source/s/simpleeval/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A quick single file library for easily adding evaluatable expressions
into python projects. Say you want to allow a user to set an alarm volume,
which could depend on the time of day, alarm level, how many previous alarms
had gone off, and if there is music playing at the time.

Or if you want to allow simple formulare in a web application, but don’t want
to give full eval() access, or don’t want to run in javascript on the client side.

%prep
%setup -q -n %{modname}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENCE
%{python_sitelib}/*

%changelog
* Sun Jan 14 2024 Axel Braun <axel.braun@gmx.de>
- enable %%{?sle15_python_module_pythons}
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.13:
  * Better handling of empty strings passed as input.
  * Fix the shift safe number issue from 0.9.12
  * More minor pylint / etc fixes / cleanups (general code
    quality)
  * separate `.parse` from #115
  * Allow setting up completely empty `{}` operators / functions
  * Add extra bit-ops from #87
* Wed Feb 23 2022 pgajdos@suse.com
- version update to 0.9.12
  * Remove Cyclic references (memory leak)
  * Add left & right shift operations (<< and >>)
  * Switch to GH actions & CodeCov.io for CI tests
  * Add extra contributors details
  * Reformat w/ Black + isort, and have linting of those in CI
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.10:
  * minor fixes
  * support for python 3.8
* Fri Oct  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Run fdupes
- Remove not really needed commands from build
* Wed Apr 24 2019 pgajdos@suse.com
- version update to 0.9.8
  * no upstream changelog
- run the test suite
- run spec cleaner
- added sources
  https://github.com/danthedeckie/simpleeval/issues/55
  + LICENCE
* Wed May  3 2017 axel.braun@gmx.de
- changes for singlespec
* Tue Apr 21 2015 axel.braun@gmx.de
- Initial build on OBS
- version 0.8.2
